/**
 * This file is part of the dcrypt project.
 *
 * Copyright: Copyright (C) dcrypt contributors 2008. All rights reserved.
 * License:   MIT
 * Authors:   Thomas Dixon
 */

module dcrypt.crypto.StreamCipherWrapper;

import dcrypt.crypto.SymmetricCipher;
import dcrypt.crypto.StreamCipher;
public import dcrypt.crypto.params.CipherParameters;

/** High-level API for stream ciphers. */
class StreamCipherWrapper : SymmetricCipher {
    private StreamCipher cipher;
    
    this(StreamCipher sc) {
        cipher = sc;
    }
    
    void init(bool encrypt, CipherParameters params) {
        cipher.init(encrypt, params);
    }

    uint update(void[] input_, uint inOff, 
                    uint len, void[] output_, uint outOff) {
        cipher.processBytes(input_, inOff, len, output_, outOff);
        return len;
    }
    
    uint finish(void[] output_, uint outOff) {
        return 0;
    }
    
    void reset() {
        cipher.reset();
    }
    
    char[] name() {
        return cipher.name;
    }
}
